==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebSwitchDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCheckboxBaseDescriptionMetadata } from "./WebCheckboxBaseDescriptionMetadata";
import { WebSwitchDescription } from "./WebSwitchDescription";
/**
 * @hidden
 */
export let WebSwitchDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSwitchDescriptionMetadata extends Base {
        static b(a) {
            if (WebSwitchDescriptionMetadata.a == null) {
                WebSwitchDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSwitchDescriptionMetadata.c(WebSwitchDescriptionMetadata.a);
            }
            if (a.k(WebSwitchDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebSwitchDescriptionMetadata.a);
        }
        static c(a) {
            WebCheckboxBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Switch");
            a.item("__tagNameWC", "String:igc-switch");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebSwitchDescriptionMetadata.b(a);
            a.ad("WebSwitch", () => new WebSwitchDescription());
            a.ac("WebSwitch", WebSwitchDescriptionMetadata.a);
        }
    }
    WebSwitchDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSwitchDescriptionMetadata, 'WebSwitchDescriptionMetadata');
    WebSwitchDescriptionMetadata.a = null;
    return WebSwitchDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebSwitchDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCheckboxBaseDescriptionMetadata } from "./WebCheckboxBaseDescriptionMetadata";
import { WebSwitchDescription } from "./WebSwitchDescription";
/**
 * @hidden
 */
export let WebSwitchDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSwitchDescriptionMetadata extends Base {
        static b(a) {
            if (WebSwitchDescriptionMetadata.a == null) {
                WebSwitchDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSwitchDescriptionMetadata.c(WebSwitchDescriptionMetadata.a);
            }
            if (a.k(WebSwitchDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebSwitchDescriptionMetadata.a);
        }
        static c(a) {
            WebCheckboxBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Switch");
            a.item("__tagNameWC", "String:igc-switch");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebSwitchDescriptionMetadata.b(a);
            a.ae("WebSwitch", () => new WebSwitchDescription());
            a.ad("WebSwitch", WebSwitchDescriptionMetadata.a);
        }
    }
    WebSwitchDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSwitchDescriptionMetadata, 'WebSwitchDescriptionMetadata');
    WebSwitchDescriptionMetadata.a = null;
    return WebSwitchDescriptionMetadata;
})();
